@@ -30,6 +30,8 @@
 
 snowWorkers <- function() {
     cores <- max(1L, parallel::detectCores() - 2L)
+    if (nzchar(Sys.getenv("BBS_HOME")))
+        cores <- min(4L, cores)
     getOption("mc.cores", cores)
 }
 
@@ -204,7 +206,8 @@ setMethod("bpstart", "SnowParam",
         stop("cluster not started; no workers specified")
 
     nnodes <- min(bpnworkers(x), lenX)
-    if (nnodes > 128L - nrow(showConnections(all=TRUE)))
+    if (x$.clusterargs$type != "MPI" &&
+        (nnodes > 128L - nrow(showConnections(all=TRUE))))
         stop("cannot create ", nnodes, " workers; ",
              128L - nrow(showConnections(all=TRUE)),
              " connections available in this session")
@@ -213,6 +216,7 @@ setMethod("bpstart", "SnowParam",
     if (x$.clusterargs$type == "FORK") {
         bpbackend(x) <-
             .bpmakeForkCluster(nnodes, bptimeout(x),
+                               getOption("bphost", Sys.info()[["nodename"]]),
                                getOption("ports", NA_integer_))
     ## SOCK, MPI
     } else {
