@@ -5,15 +5,17 @@
     result[setdiff(names(result), names(.BiocParallelParam$fields()))]
 }
 
-.splitIndices <- function (nx, ncl)
+.splitIndices <- function (nx, tasks)
 {
     ## derived from parallel
     i <- seq_len(nx)
-    if (ncl <= 1L || nx <= 1L)  # allow nx, nc == 0
-        i
+    if (nx == 0L)
+        list()
+    else if (tasks <= 1L || nx == 1L)  # allow nx, nc == 0
+        list(i)
     else {
-        fuzz <- min((nx - 1L)/1000, 0.4 * nx/ncl)
-        breaks <- seq(1 - fuzz, nx + fuzz, length = ncl + 1L)
+        fuzz <- min((nx - 1L)/1000, 0.4 * nx / tasks)
+        breaks <- seq(1 - fuzz, nx + fuzz, length = tasks + 1L)
         si <- structure(split(i, cut(i, breaks)), names = NULL)
         si[sapply(si, length) != 0]
     }
@@ -21,15 +23,27 @@
 
 .splitX <- function(X, workers, tasks) 
 {
-    if (tasks == 1 || length(X) == 1L)
-        return(list(X))
-    else if (tasks == 0)
-        idx <- .splitIndices(length(X), workers)
-    else
-        idx <- .splitIndices(length(X), min(tasks, length(X)))
+    if (tasks == 0L)
+        tasks <- workers
+    idx <- .splitIndices(length(X), tasks)
     relist(X, idx)
 }
 
+.redo_index <-
+    function(X, BPREDO, verbose=TRUE)
+{
+    idx <- !bpok(BPREDO)
+    if (length(idx)) {
+        if (length(BPREDO) != length(X))
+            stop("'length(BPREDO)' must equal 'length(X)'")
+        if (!any(idx))
+            stop("no previous error in 'BPREDO'")
+        if (verbose)
+            message("resuming previous calculation ... ")
+    }
+    idx
+}
+
 .rename <-
     function(results, dots, USE.NAMES=FALSE)
 {
@@ -57,16 +71,16 @@
 {
     ddd <- list(...)
     if (!length(ddd))
-      return(list())
+        return(list())
     len <- vapply(ddd, length, integer(1L))
     if (!all(len == len[1L])) {
         max.len <- max(len)
         if (max.len && any(len == 0L))
             stop("zero-length and non-zero length inputs cannot be mixed")
         if (any(max.len %% len))
-            warning("Longer argument not a multiple of length of vector")
+            warning("longer argument not a multiple of length of vector")
         ddd <- lapply(ddd, rep_len, length.out=max.len)
     }
 
-  return(ddd)
+    ddd
 }
